-----------------------------------------------------------------------------------------------
-- Client Lua Script for LeaveGroupWarning
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"
require "Apollo"
require "GroupLib"
require "MatchingGameLib"

-----------------------------------------------------------------------------------------------
-- LeaveGroupWarning Module Definition
-----------------------------------------------------------------------------------------------
local LeaveGroupWarning = {}


function LeaveGroupWarning:new(o)
  o = o or {}
  setmetatable(o, self)
  self.__index = self

  return o
end

function LeaveGroupWarning:Init()
  Apollo.RegisterAddon(self, false, "", "MatchMaker")
end

function LeaveGroupWarning:OnLoad()
  self.xmlDoc = XmlDoc.CreateFromFile("LeaveGroupWarning.xml")

  Apollo.GetAddon("MatchMaker").OnLeaveGroupBtn = function() self:DisplayWarning() end
end

function LeaveGroupWarning:DisplayWarning()
  if not self.xmlDoc then
    Print("Couldn't load the warning for some reason use /leave instead.")
    return
  elseif not self.xmlDoc:IsLoaded() then
    self.xmlDoc:RegisterCallback("DisplayWarning", self)
    return
  end

  -- No deserter buff when in a solo group or in a finished game
  if GroupLib.GetMemberCount() == 1 or MatchingGameLib.IsFinished() then
    self:OnAccept()
  elseif not self.wndWarning then
    self.wndWarning = Apollo.LoadForm(self.xmlDoc, "LeaveGroup", nil, self)
    self.wndWarning:Show(true)
    self.wndWarning:ToFront()
  end
end

function LeaveGroupWarning:OnAccept( wndHandler, wndControl, eMouseButton )
  if MatchingGameLib.IsInGameInstance() then
    MatchingGameLib.LeaveGame()
  end
  self:Close()
end

function LeaveGroupWarning:OnDecline( wndHandler, wndControl, eMouseButton )
  self:Close()
end

function LeaveGroupWarning:Close()
  if self.wndWarning then
    self.wndWarning:Close()
    self.wndWarning = nil
  end
end

-----------------------------------------------------------------------------------------------
-- LeaveGroupWarning Instance
-----------------------------------------------------------------------------------------------
local LeaveGroupWarningInst = LeaveGroupWarning:new()
LeaveGroupWarningInst:Init()
